
# Slot: comments


notes and comments about an element intended for external consumption

URI: [linkml:comments](https://w3id.org/linkml/comments)


## Domain and Range

[Element](Element.md) &#8594;  <sub>0..\*</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [AnonymousClassExpression](AnonymousClassExpression.md)
 * [AnonymousExpression](AnonymousExpression.md)
 * [AnonymousSlotExpression](AnonymousSlotExpression.md)
 * [ClassDefinition](ClassDefinition.md)
 * [ClassRule](ClassRule.md)
 * [CommonMetadata](CommonMetadata.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [EnumDefinition](EnumDefinition.md)
 * [PermissibleValue](PermissibleValue.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)
 * [UniqueKey](UniqueKey.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:note |
| **In Subsets:** | | owl |

